# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['DataFlowArgs', 'DataFlow']

@pulumi.input_type
class DataFlowArgs:
    def __init__(__self__, *,
                 file_system_id: pulumi.Input[str],
                 fset_id: pulumi.Input[str],
                 source_storage: pulumi.Input[str],
                 throughput: pulumi.Input[int],
                 description: Optional[pulumi.Input[str]] = None,
                 dry_run: Optional[pulumi.Input[bool]] = None,
                 source_security_type: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a DataFlow resource.
        :param pulumi.Input[str] file_system_id: The ID of the file system.
        :param pulumi.Input[str] fset_id: The ID of the Fileset.
        :param pulumi.Input[str] source_storage: The access path of the source store. Format: `<storage type>://<path>`. Among them:
               - storage type: currently only OSS is supported.
               - path: the bucket name of OSS.
               - Only lowercase letters, numbers, and dashes (-) are supported and must start and end with lowercase letters or numbers.
        :param pulumi.Input[int] throughput: The maximum transmission bandwidth of data flow, unit: `MB/s`. Valid values: `1200`, `1500`, `600`. **NOTE:** The transmission bandwidth of data flow must be less than the IO bandwidth of the file system.
        :param pulumi.Input[str] description: The Description of the data flow. Restrictions:
        :param pulumi.Input[bool] dry_run: The dry run.
        :param pulumi.Input[str] source_security_type: The security protection type of the source storage. If the source storage must be accessed through security protection, specify the security protection type of the source storage. Value:
        :param pulumi.Input[str] status: The status of the Data flow. Valid values: `Running`, `Stopped`.
        """
        pulumi.set(__self__, "file_system_id", file_system_id)
        pulumi.set(__self__, "fset_id", fset_id)
        pulumi.set(__self__, "source_storage", source_storage)
        pulumi.set(__self__, "throughput", throughput)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if dry_run is not None:
            pulumi.set(__self__, "dry_run", dry_run)
        if source_security_type is not None:
            pulumi.set(__self__, "source_security_type", source_security_type)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="fileSystemId")
    def file_system_id(self) -> pulumi.Input[str]:
        """
        The ID of the file system.
        """
        return pulumi.get(self, "file_system_id")

    @file_system_id.setter
    def file_system_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "file_system_id", value)

    @property
    @pulumi.getter(name="fsetId")
    def fset_id(self) -> pulumi.Input[str]:
        """
        The ID of the Fileset.
        """
        return pulumi.get(self, "fset_id")

    @fset_id.setter
    def fset_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "fset_id", value)

    @property
    @pulumi.getter(name="sourceStorage")
    def source_storage(self) -> pulumi.Input[str]:
        """
        The access path of the source store. Format: `<storage type>://<path>`. Among them:
        - storage type: currently only OSS is supported.
        - path: the bucket name of OSS.
        - Only lowercase letters, numbers, and dashes (-) are supported and must start and end with lowercase letters or numbers.
        """
        return pulumi.get(self, "source_storage")

    @source_storage.setter
    def source_storage(self, value: pulumi.Input[str]):
        pulumi.set(self, "source_storage", value)

    @property
    @pulumi.getter
    def throughput(self) -> pulumi.Input[int]:
        """
        The maximum transmission bandwidth of data flow, unit: `MB/s`. Valid values: `1200`, `1500`, `600`. **NOTE:** The transmission bandwidth of data flow must be less than the IO bandwidth of the file system.
        """
        return pulumi.get(self, "throughput")

    @throughput.setter
    def throughput(self, value: pulumi.Input[int]):
        pulumi.set(self, "throughput", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The Description of the data flow. Restrictions:
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> Optional[pulumi.Input[bool]]:
        """
        The dry run.
        """
        return pulumi.get(self, "dry_run")

    @dry_run.setter
    def dry_run(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "dry_run", value)

    @property
    @pulumi.getter(name="sourceSecurityType")
    def source_security_type(self) -> Optional[pulumi.Input[str]]:
        """
        The security protection type of the source storage. If the source storage must be accessed through security protection, specify the security protection type of the source storage. Value:
        """
        return pulumi.get(self, "source_security_type")

    @source_security_type.setter
    def source_security_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_security_type", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the Data flow. Valid values: `Running`, `Stopped`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


@pulumi.input_type
class _DataFlowState:
    def __init__(__self__, *,
                 data_flow_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 dry_run: Optional[pulumi.Input[bool]] = None,
                 file_system_id: Optional[pulumi.Input[str]] = None,
                 fset_id: Optional[pulumi.Input[str]] = None,
                 source_security_type: Optional[pulumi.Input[str]] = None,
                 source_storage: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 throughput: Optional[pulumi.Input[int]] = None):
        """
        Input properties used for looking up and filtering DataFlow resources.
        :param pulumi.Input[str] data_flow_id: The ID of the Data flow.
        :param pulumi.Input[str] description: The Description of the data flow. Restrictions:
        :param pulumi.Input[bool] dry_run: The dry run.
        :param pulumi.Input[str] file_system_id: The ID of the file system.
        :param pulumi.Input[str] fset_id: The ID of the Fileset.
        :param pulumi.Input[str] source_security_type: The security protection type of the source storage. If the source storage must be accessed through security protection, specify the security protection type of the source storage. Value:
        :param pulumi.Input[str] source_storage: The access path of the source store. Format: `<storage type>://<path>`. Among them:
               - storage type: currently only OSS is supported.
               - path: the bucket name of OSS.
               - Only lowercase letters, numbers, and dashes (-) are supported and must start and end with lowercase letters or numbers.
        :param pulumi.Input[str] status: The status of the Data flow. Valid values: `Running`, `Stopped`.
        :param pulumi.Input[int] throughput: The maximum transmission bandwidth of data flow, unit: `MB/s`. Valid values: `1200`, `1500`, `600`. **NOTE:** The transmission bandwidth of data flow must be less than the IO bandwidth of the file system.
        """
        if data_flow_id is not None:
            pulumi.set(__self__, "data_flow_id", data_flow_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if dry_run is not None:
            pulumi.set(__self__, "dry_run", dry_run)
        if file_system_id is not None:
            pulumi.set(__self__, "file_system_id", file_system_id)
        if fset_id is not None:
            pulumi.set(__self__, "fset_id", fset_id)
        if source_security_type is not None:
            pulumi.set(__self__, "source_security_type", source_security_type)
        if source_storage is not None:
            pulumi.set(__self__, "source_storage", source_storage)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if throughput is not None:
            pulumi.set(__self__, "throughput", throughput)

    @property
    @pulumi.getter(name="dataFlowId")
    def data_flow_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Data flow.
        """
        return pulumi.get(self, "data_flow_id")

    @data_flow_id.setter
    def data_flow_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "data_flow_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The Description of the data flow. Restrictions:
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> Optional[pulumi.Input[bool]]:
        """
        The dry run.
        """
        return pulumi.get(self, "dry_run")

    @dry_run.setter
    def dry_run(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "dry_run", value)

    @property
    @pulumi.getter(name="fileSystemId")
    def file_system_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the file system.
        """
        return pulumi.get(self, "file_system_id")

    @file_system_id.setter
    def file_system_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "file_system_id", value)

    @property
    @pulumi.getter(name="fsetId")
    def fset_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Fileset.
        """
        return pulumi.get(self, "fset_id")

    @fset_id.setter
    def fset_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "fset_id", value)

    @property
    @pulumi.getter(name="sourceSecurityType")
    def source_security_type(self) -> Optional[pulumi.Input[str]]:
        """
        The security protection type of the source storage. If the source storage must be accessed through security protection, specify the security protection type of the source storage. Value:
        """
        return pulumi.get(self, "source_security_type")

    @source_security_type.setter
    def source_security_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_security_type", value)

    @property
    @pulumi.getter(name="sourceStorage")
    def source_storage(self) -> Optional[pulumi.Input[str]]:
        """
        The access path of the source store. Format: `<storage type>://<path>`. Among them:
        - storage type: currently only OSS is supported.
        - path: the bucket name of OSS.
        - Only lowercase letters, numbers, and dashes (-) are supported and must start and end with lowercase letters or numbers.
        """
        return pulumi.get(self, "source_storage")

    @source_storage.setter
    def source_storage(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_storage", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the Data flow. Valid values: `Running`, `Stopped`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def throughput(self) -> Optional[pulumi.Input[int]]:
        """
        The maximum transmission bandwidth of data flow, unit: `MB/s`. Valid values: `1200`, `1500`, `600`. **NOTE:** The transmission bandwidth of data flow must be less than the IO bandwidth of the file system.
        """
        return pulumi.get(self, "throughput")

    @throughput.setter
    def throughput(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "throughput", value)


class DataFlow(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 dry_run: Optional[pulumi.Input[bool]] = None,
                 file_system_id: Optional[pulumi.Input[str]] = None,
                 fset_id: Optional[pulumi.Input[str]] = None,
                 source_security_type: Optional[pulumi.Input[str]] = None,
                 source_storage: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 throughput: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        Provides a Network Attached Storage (NAS) Data Flow resource.

        For information about Network Attached Storage (NAS) Data Flow and how to use it, see [What is Data Flow](https://www.alibabacloud.com/help/en/doc-detail/27530.html).

        > **NOTE:** Available in v1.153.0+.

        ## Import

        Network Attached Storage (NAS) Data Flow can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:nas/dataFlow:DataFlow example <file_system_id>:<data_flow_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: The Description of the data flow. Restrictions:
        :param pulumi.Input[bool] dry_run: The dry run.
        :param pulumi.Input[str] file_system_id: The ID of the file system.
        :param pulumi.Input[str] fset_id: The ID of the Fileset.
        :param pulumi.Input[str] source_security_type: The security protection type of the source storage. If the source storage must be accessed through security protection, specify the security protection type of the source storage. Value:
        :param pulumi.Input[str] source_storage: The access path of the source store. Format: `<storage type>://<path>`. Among them:
               - storage type: currently only OSS is supported.
               - path: the bucket name of OSS.
               - Only lowercase letters, numbers, and dashes (-) are supported and must start and end with lowercase letters or numbers.
        :param pulumi.Input[str] status: The status of the Data flow. Valid values: `Running`, `Stopped`.
        :param pulumi.Input[int] throughput: The maximum transmission bandwidth of data flow, unit: `MB/s`. Valid values: `1200`, `1500`, `600`. **NOTE:** The transmission bandwidth of data flow must be less than the IO bandwidth of the file system.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DataFlowArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Network Attached Storage (NAS) Data Flow resource.

        For information about Network Attached Storage (NAS) Data Flow and how to use it, see [What is Data Flow](https://www.alibabacloud.com/help/en/doc-detail/27530.html).

        > **NOTE:** Available in v1.153.0+.

        ## Import

        Network Attached Storage (NAS) Data Flow can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:nas/dataFlow:DataFlow example <file_system_id>:<data_flow_id>
        ```

        :param str resource_name: The name of the resource.
        :param DataFlowArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DataFlowArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 dry_run: Optional[pulumi.Input[bool]] = None,
                 file_system_id: Optional[pulumi.Input[str]] = None,
                 fset_id: Optional[pulumi.Input[str]] = None,
                 source_security_type: Optional[pulumi.Input[str]] = None,
                 source_storage: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 throughput: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DataFlowArgs.__new__(DataFlowArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["dry_run"] = dry_run
            if file_system_id is None and not opts.urn:
                raise TypeError("Missing required property 'file_system_id'")
            __props__.__dict__["file_system_id"] = file_system_id
            if fset_id is None and not opts.urn:
                raise TypeError("Missing required property 'fset_id'")
            __props__.__dict__["fset_id"] = fset_id
            __props__.__dict__["source_security_type"] = source_security_type
            if source_storage is None and not opts.urn:
                raise TypeError("Missing required property 'source_storage'")
            __props__.__dict__["source_storage"] = source_storage
            __props__.__dict__["status"] = status
            if throughput is None and not opts.urn:
                raise TypeError("Missing required property 'throughput'")
            __props__.__dict__["throughput"] = throughput
            __props__.__dict__["data_flow_id"] = None
        super(DataFlow, __self__).__init__(
            'alicloud:nas/dataFlow:DataFlow',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            data_flow_id: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            dry_run: Optional[pulumi.Input[bool]] = None,
            file_system_id: Optional[pulumi.Input[str]] = None,
            fset_id: Optional[pulumi.Input[str]] = None,
            source_security_type: Optional[pulumi.Input[str]] = None,
            source_storage: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            throughput: Optional[pulumi.Input[int]] = None) -> 'DataFlow':
        """
        Get an existing DataFlow resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] data_flow_id: The ID of the Data flow.
        :param pulumi.Input[str] description: The Description of the data flow. Restrictions:
        :param pulumi.Input[bool] dry_run: The dry run.
        :param pulumi.Input[str] file_system_id: The ID of the file system.
        :param pulumi.Input[str] fset_id: The ID of the Fileset.
        :param pulumi.Input[str] source_security_type: The security protection type of the source storage. If the source storage must be accessed through security protection, specify the security protection type of the source storage. Value:
        :param pulumi.Input[str] source_storage: The access path of the source store. Format: `<storage type>://<path>`. Among them:
               - storage type: currently only OSS is supported.
               - path: the bucket name of OSS.
               - Only lowercase letters, numbers, and dashes (-) are supported and must start and end with lowercase letters or numbers.
        :param pulumi.Input[str] status: The status of the Data flow. Valid values: `Running`, `Stopped`.
        :param pulumi.Input[int] throughput: The maximum transmission bandwidth of data flow, unit: `MB/s`. Valid values: `1200`, `1500`, `600`. **NOTE:** The transmission bandwidth of data flow must be less than the IO bandwidth of the file system.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DataFlowState.__new__(_DataFlowState)

        __props__.__dict__["data_flow_id"] = data_flow_id
        __props__.__dict__["description"] = description
        __props__.__dict__["dry_run"] = dry_run
        __props__.__dict__["file_system_id"] = file_system_id
        __props__.__dict__["fset_id"] = fset_id
        __props__.__dict__["source_security_type"] = source_security_type
        __props__.__dict__["source_storage"] = source_storage
        __props__.__dict__["status"] = status
        __props__.__dict__["throughput"] = throughput
        return DataFlow(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="dataFlowId")
    def data_flow_id(self) -> pulumi.Output[str]:
        """
        The ID of the Data flow.
        """
        return pulumi.get(self, "data_flow_id")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        The Description of the data flow. Restrictions:
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> pulumi.Output[Optional[bool]]:
        """
        The dry run.
        """
        return pulumi.get(self, "dry_run")

    @property
    @pulumi.getter(name="fileSystemId")
    def file_system_id(self) -> pulumi.Output[str]:
        """
        The ID of the file system.
        """
        return pulumi.get(self, "file_system_id")

    @property
    @pulumi.getter(name="fsetId")
    def fset_id(self) -> pulumi.Output[str]:
        """
        The ID of the Fileset.
        """
        return pulumi.get(self, "fset_id")

    @property
    @pulumi.getter(name="sourceSecurityType")
    def source_security_type(self) -> pulumi.Output[str]:
        """
        The security protection type of the source storage. If the source storage must be accessed through security protection, specify the security protection type of the source storage. Value:
        """
        return pulumi.get(self, "source_security_type")

    @property
    @pulumi.getter(name="sourceStorage")
    def source_storage(self) -> pulumi.Output[str]:
        """
        The access path of the source store. Format: `<storage type>://<path>`. Among them:
        - storage type: currently only OSS is supported.
        - path: the bucket name of OSS.
        - Only lowercase letters, numbers, and dashes (-) are supported and must start and end with lowercase letters or numbers.
        """
        return pulumi.get(self, "source_storage")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the Data flow. Valid values: `Running`, `Stopped`.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def throughput(self) -> pulumi.Output[int]:
        """
        The maximum transmission bandwidth of data flow, unit: `MB/s`. Valid values: `1200`, `1500`, `600`. **NOTE:** The transmission bandwidth of data flow must be less than the IO bandwidth of the file system.
        """
        return pulumi.get(self, "throughput")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'ConnectionIkeConfigArgs',
    'ConnectionIpsecConfigArgs',
]

@pulumi.input_type
class ConnectionIkeConfigArgs:
    def __init__(__self__, *,
                 ike_auth_alg: Optional[pulumi.Input[str]] = None,
                 ike_enc_alg: Optional[pulumi.Input[str]] = None,
                 ike_lifetime: Optional[pulumi.Input[int]] = None,
                 ike_local_id: Optional[pulumi.Input[str]] = None,
                 ike_mode: Optional[pulumi.Input[str]] = None,
                 ike_pfs: Optional[pulumi.Input[str]] = None,
                 ike_remote_id: Optional[pulumi.Input[str]] = None,
                 ike_version: Optional[pulumi.Input[str]] = None,
                 psk: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] ike_auth_alg: The authentication algorithm of phase-one negotiation. Valid value: md5 | sha1 . Default value: md5
        :param pulumi.Input[str] ike_enc_alg: The encryption algorithm of phase-one negotiation. Valid value: aes | aes192 | aes256 | des | 3des. Default Valid value: aes
        :param pulumi.Input[int] ike_lifetime: The SA lifecycle as the result of phase-one negotiation. The valid value of n is [0, 86400], the unit is second and the default value is 86400.
        :param pulumi.Input[str] ike_local_id: The identification of the VPN gateway.
        :param pulumi.Input[str] ike_mode: The negotiation mode of IKE V1. Valid value: main (main mode) | aggressive (aggressive mode). Default value: main
        :param pulumi.Input[str] ike_pfs: The Diffie-Hellman key exchange algorithm used by phase-one negotiation. Valid value: group1 | group2 | group5 | group14 | group24. Default value: group2
        :param pulumi.Input[str] ike_remote_id: The identification of the customer gateway.
        :param pulumi.Input[str] ike_version: The version of the IKE protocol. Valid value: ikev1 | ikev2. Default value: ikev1
        :param pulumi.Input[str] psk: Used for authentication between the IPsec VPN gateway and the customer gateway.
        """
        if ike_auth_alg is not None:
            pulumi.set(__self__, "ike_auth_alg", ike_auth_alg)
        if ike_enc_alg is not None:
            pulumi.set(__self__, "ike_enc_alg", ike_enc_alg)
        if ike_lifetime is not None:
            pulumi.set(__self__, "ike_lifetime", ike_lifetime)
        if ike_local_id is not None:
            pulumi.set(__self__, "ike_local_id", ike_local_id)
        if ike_mode is not None:
            pulumi.set(__self__, "ike_mode", ike_mode)
        if ike_pfs is not None:
            pulumi.set(__self__, "ike_pfs", ike_pfs)
        if ike_remote_id is not None:
            pulumi.set(__self__, "ike_remote_id", ike_remote_id)
        if ike_version is not None:
            pulumi.set(__self__, "ike_version", ike_version)
        if psk is not None:
            pulumi.set(__self__, "psk", psk)

    @property
    @pulumi.getter(name="ikeAuthAlg")
    def ike_auth_alg(self) -> Optional[pulumi.Input[str]]:
        """
        The authentication algorithm of phase-one negotiation. Valid value: md5 | sha1 . Default value: md5
        """
        return pulumi.get(self, "ike_auth_alg")

    @ike_auth_alg.setter
    def ike_auth_alg(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ike_auth_alg", value)

    @property
    @pulumi.getter(name="ikeEncAlg")
    def ike_enc_alg(self) -> Optional[pulumi.Input[str]]:
        """
        The encryption algorithm of phase-one negotiation. Valid value: aes | aes192 | aes256 | des | 3des. Default Valid value: aes
        """
        return pulumi.get(self, "ike_enc_alg")

    @ike_enc_alg.setter
    def ike_enc_alg(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ike_enc_alg", value)

    @property
    @pulumi.getter(name="ikeLifetime")
    def ike_lifetime(self) -> Optional[pulumi.Input[int]]:
        """
        The SA lifecycle as the result of phase-one negotiation. The valid value of n is [0, 86400], the unit is second and the default value is 86400.
        """
        return pulumi.get(self, "ike_lifetime")

    @ike_lifetime.setter
    def ike_lifetime(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "ike_lifetime", value)

    @property
    @pulumi.getter(name="ikeLocalId")
    def ike_local_id(self) -> Optional[pulumi.Input[str]]:
        """
        The identification of the VPN gateway.
        """
        return pulumi.get(self, "ike_local_id")

    @ike_local_id.setter
    def ike_local_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ike_local_id", value)

    @property
    @pulumi.getter(name="ikeMode")
    def ike_mode(self) -> Optional[pulumi.Input[str]]:
        """
        The negotiation mode of IKE V1. Valid value: main (main mode) | aggressive (aggressive mode). Default value: main
        """
        return pulumi.get(self, "ike_mode")

    @ike_mode.setter
    def ike_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ike_mode", value)

    @property
    @pulumi.getter(name="ikePfs")
    def ike_pfs(self) -> Optional[pulumi.Input[str]]:
        """
        The Diffie-Hellman key exchange algorithm used by phase-one negotiation. Valid value: group1 | group2 | group5 | group14 | group24. Default value: group2
        """
        return pulumi.get(self, "ike_pfs")

    @ike_pfs.setter
    def ike_pfs(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ike_pfs", value)

    @property
    @pulumi.getter(name="ikeRemoteId")
    def ike_remote_id(self) -> Optional[pulumi.Input[str]]:
        """
        The identification of the customer gateway.
        """
        return pulumi.get(self, "ike_remote_id")

    @ike_remote_id.setter
    def ike_remote_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ike_remote_id", value)

    @property
    @pulumi.getter(name="ikeVersion")
    def ike_version(self) -> Optional[pulumi.Input[str]]:
        """
        The version of the IKE protocol. Valid value: ikev1 | ikev2. Default value: ikev1
        """
        return pulumi.get(self, "ike_version")

    @ike_version.setter
    def ike_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ike_version", value)

    @property
    @pulumi.getter
    def psk(self) -> Optional[pulumi.Input[str]]:
        """
        Used for authentication between the IPsec VPN gateway and the customer gateway.
        """
        return pulumi.get(self, "psk")

    @psk.setter
    def psk(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "psk", value)


@pulumi.input_type
class ConnectionIpsecConfigArgs:
    def __init__(__self__, *,
                 ipsec_auth_alg: Optional[pulumi.Input[str]] = None,
                 ipsec_enc_alg: Optional[pulumi.Input[str]] = None,
                 ipsec_lifetime: Optional[pulumi.Input[int]] = None,
                 ipsec_pfs: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] ipsec_auth_alg: The authentication algorithm of phase-two negotiation. Valid value: md5 | sha1 | sha256 | sha384 | sha512 |. Default value: sha1
        :param pulumi.Input[str] ipsec_enc_alg: The encryption algorithm of phase-two negotiation. Valid value: aes | aes192 | aes256 | des | 3des. Default value: aes
        :param pulumi.Input[int] ipsec_lifetime: The SA lifecycle as the result of phase-two negotiation. The valid value is [0, 86400], the unit is second and the default value is 86400.
        :param pulumi.Input[str] ipsec_pfs: The Diffie-Hellman key exchange algorithm used by phase-two negotiation. Valid value: group1 | group2 | group5 | group14 | group24| disabled. Default value: group2
        """
        if ipsec_auth_alg is not None:
            pulumi.set(__self__, "ipsec_auth_alg", ipsec_auth_alg)
        if ipsec_enc_alg is not None:
            pulumi.set(__self__, "ipsec_enc_alg", ipsec_enc_alg)
        if ipsec_lifetime is not None:
            pulumi.set(__self__, "ipsec_lifetime", ipsec_lifetime)
        if ipsec_pfs is not None:
            pulumi.set(__self__, "ipsec_pfs", ipsec_pfs)

    @property
    @pulumi.getter(name="ipsecAuthAlg")
    def ipsec_auth_alg(self) -> Optional[pulumi.Input[str]]:
        """
        The authentication algorithm of phase-two negotiation. Valid value: md5 | sha1 | sha256 | sha384 | sha512 |. Default value: sha1
        """
        return pulumi.get(self, "ipsec_auth_alg")

    @ipsec_auth_alg.setter
    def ipsec_auth_alg(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ipsec_auth_alg", value)

    @property
    @pulumi.getter(name="ipsecEncAlg")
    def ipsec_enc_alg(self) -> Optional[pulumi.Input[str]]:
        """
        The encryption algorithm of phase-two negotiation. Valid value: aes | aes192 | aes256 | des | 3des. Default value: aes
        """
        return pulumi.get(self, "ipsec_enc_alg")

    @ipsec_enc_alg.setter
    def ipsec_enc_alg(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ipsec_enc_alg", value)

    @property
    @pulumi.getter(name="ipsecLifetime")
    def ipsec_lifetime(self) -> Optional[pulumi.Input[int]]:
        """
        The SA lifecycle as the result of phase-two negotiation. The valid value is [0, 86400], the unit is second and the default value is 86400.
        """
        return pulumi.get(self, "ipsec_lifetime")

    @ipsec_lifetime.setter
    def ipsec_lifetime(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "ipsec_lifetime", value)

    @property
    @pulumi.getter(name="ipsecPfs")
    def ipsec_pfs(self) -> Optional[pulumi.Input[str]]:
        """
        The Diffie-Hellman key exchange algorithm used by phase-two negotiation. Valid value: group1 | group2 | group5 | group14 | group24| disabled. Default value: group2
        """
        return pulumi.get(self, "ipsec_pfs")

    @ipsec_pfs.setter
    def ipsec_pfs(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ipsec_pfs", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from .change_set import *
from .get_change_sets import *
from .get_regions import *
from .get_stack_groups import *
from .get_stack_instances import *
from .get_stacks import *
from .get_template_scratches import *
from .get_templates import *
from .stack import *
from .stack_group import *
from .stack_instance import *
from .template import *
from .template_scratch import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetApplicationsApplicationResult',
    'GetClustersClusterResult',
    'GetDeployGroupsGroupResult',
]

@pulumi.output_type
class GetApplicationsApplicationResult(dict):
    def __init__(__self__, *,
                 app_id: str,
                 app_name: str,
                 application_type: str,
                 build_package_id: int,
                 cluster_id: str,
                 cluster_type: int,
                 region_id: str):
        """
        :param str app_id: The ID of the application that you want to deploy.
        :param str app_name: The name of your EDAS application. Only letters '-' '_' and numbers are allowed. The length cannot exceed 36 characters.
        :param str application_type: The type of the package for the deployment of the application that you want to create. The valid values are: WAR and JAR. We strongly recommend you to set this parameter when creating the application.
        :param int build_package_id: The package ID of Enterprise Distributed Application Service (EDAS) Container.
        :param str cluster_id: The ID of the cluster that you want to create the application.
        :param int cluster_type: The type of the cluster that you want to create. Valid values: 1: Swarm cluster. 2: ECS cluster. 3: Kubernates cluster.
        :param str region_id: The ID of the namespace the application belongs to.
        """
        pulumi.set(__self__, "app_id", app_id)
        pulumi.set(__self__, "app_name", app_name)
        pulumi.set(__self__, "application_type", application_type)
        pulumi.set(__self__, "build_package_id", build_package_id)
        pulumi.set(__self__, "cluster_id", cluster_id)
        pulumi.set(__self__, "cluster_type", cluster_type)
        pulumi.set(__self__, "region_id", region_id)

    @property
    @pulumi.getter(name="appId")
    def app_id(self) -> str:
        """
        The ID of the application that you want to deploy.
        """
        return pulumi.get(self, "app_id")

    @property
    @pulumi.getter(name="appName")
    def app_name(self) -> str:
        """
        The name of your EDAS application. Only letters '-' '_' and numbers are allowed. The length cannot exceed 36 characters.
        """
        return pulumi.get(self, "app_name")

    @property
    @pulumi.getter(name="applicationType")
    def application_type(self) -> str:
        """
        The type of the package for the deployment of the application that you want to create. The valid values are: WAR and JAR. We strongly recommend you to set this parameter when creating the application.
        """
        return pulumi.get(self, "application_type")

    @property
    @pulumi.getter(name="buildPackageId")
    def build_package_id(self) -> int:
        """
        The package ID of Enterprise Distributed Application Service (EDAS) Container.
        """
        return pulumi.get(self, "build_package_id")

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> str:
        """
        The ID of the cluster that you want to create the application.
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter(name="clusterType")
    def cluster_type(self) -> int:
        """
        The type of the cluster that you want to create. Valid values: 1: Swarm cluster. 2: ECS cluster. 3: Kubernates cluster.
        """
        return pulumi.get(self, "cluster_type")

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> str:
        """
        The ID of the namespace the application belongs to.
        """
        return pulumi.get(self, "region_id")


@pulumi.output_type
class GetClustersClusterResult(dict):
    def __init__(__self__, *,
                 cluster_id: str,
                 cluster_name: str,
                 cluster_type: int,
                 cpu: int,
                 cpu_used: int,
                 create_time: int,
                 mem: int,
                 mem_used: int,
                 network_mode: int,
                 node_num: int,
                 region_id: str,
                 update_time: int,
                 vpc_id: str):
        """
        :param str cluster_id: The ID of the cluster that you want to create the application.
        :param str cluster_name: The name of the cluster.
        :param int cluster_type: The type of the cluster, Valid values: 1: Swarm cluster. 2: ECS cluster. 3: Kubernates cluster.
        :param int cpu: The total number of CPUs in the cluster.
        :param int cpu_used: The number of used CPUs in the cluster.
        :param int create_time: Cluster's creation time.
        :param int mem: The total amount of memory in the cluser. Unit: MB.
        :param int mem_used: The amount of used memory in the cluser. Unit: MB.
        :param int network_mode: The network type of the cluster. Valid values: 1: classic network. 2: VPC.
        :param int node_num: The number of the Elastic Compute Service (ECS) instances that are deployed to the cluster.
        :param str region_id: The ID of the namespace the application belongs to.
        :param int update_time: The time when the cluster was last updated.
        :param str vpc_id: The ID of the Virtual Private Cloud (VPC) for the cluster.
        """
        pulumi.set(__self__, "cluster_id", cluster_id)
        pulumi.set(__self__, "cluster_name", cluster_name)
        pulumi.set(__self__, "cluster_type", cluster_type)
        pulumi.set(__self__, "cpu", cpu)
        pulumi.set(__self__, "cpu_used", cpu_used)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "mem", mem)
        pulumi.set(__self__, "mem_used", mem_used)
        pulumi.set(__self__, "network_mode", network_mode)
        pulumi.set(__self__, "node_num", node_num)
        pulumi.set(__self__, "region_id", region_id)
        pulumi.set(__self__, "update_time", update_time)
        pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> str:
        """
        The ID of the cluster that you want to create the application.
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> str:
        """
        The name of the cluster.
        """
        return pulumi.get(self, "cluster_name")

    @property
    @pulumi.getter(name="clusterType")
    def cluster_type(self) -> int:
        """
        The type of the cluster, Valid values: 1: Swarm cluster. 2: ECS cluster. 3: Kubernates cluster.
        """
        return pulumi.get(self, "cluster_type")

    @property
    @pulumi.getter
    def cpu(self) -> int:
        """
        The total number of CPUs in the cluster.
        """
        return pulumi.get(self, "cpu")

    @property
    @pulumi.getter(name="cpuUsed")
    def cpu_used(self) -> int:
        """
        The number of used CPUs in the cluster.
        """
        return pulumi.get(self, "cpu_used")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> int:
        """
        Cluster's creation time.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def mem(self) -> int:
        """
        The total amount of memory in the cluser. Unit: MB.
        """
        return pulumi.get(self, "mem")

    @property
    @pulumi.getter(name="memUsed")
    def mem_used(self) -> int:
        """
        The amount of used memory in the cluser. Unit: MB.
        """
        return pulumi.get(self, "mem_used")

    @property
    @pulumi.getter(name="networkMode")
    def network_mode(self) -> int:
        """
        The network type of the cluster. Valid values: 1: classic network. 2: VPC.
        """
        return pulumi.get(self, "network_mode")

    @property
    @pulumi.getter(name="nodeNum")
    def node_num(self) -> int:
        """
        The number of the Elastic Compute Service (ECS) instances that are deployed to the cluster.
        """
        return pulumi.get(self, "node_num")

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> str:
        """
        The ID of the namespace the application belongs to.
        """
        return pulumi.get(self, "region_id")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> int:
        """
        The time when the cluster was last updated.
        """
        return pulumi.get(self, "update_time")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> str:
        """
        The ID of the Virtual Private Cloud (VPC) for the cluster.
        """
        return pulumi.get(self, "vpc_id")


@pulumi.output_type
class GetDeployGroupsGroupResult(dict):
    def __init__(__self__, *,
                 app_id: str,
                 app_version_id: str,
                 cluster_id: str,
                 create_time: int,
                 group_id: str,
                 group_name: str,
                 group_type: int,
                 package_version_id: str,
                 update_time: int):
        """
        :param str app_id: ID of the EDAS application.
        :param str app_version_id: The version of the deployment package for the application.
        :param str cluster_id: The ID of the cluster that you want to create the application.
        :param int create_time: The time when the instance group was created.
        :param str group_id: The ID of the instance group.
        :param str group_name: The name of the instance group. The length cannot exceed 64 characters.
        :param int group_type: The type of the instance group. Valid values: 0: Default group. 1: Phased release is disabled for traffic management. 2: Phased release is enabled for traffic management.
        :param str package_version_id: The version of the deployment package for the instance group that was created.
        :param int update_time: The time when the instance group was updated.
        """
        pulumi.set(__self__, "app_id", app_id)
        pulumi.set(__self__, "app_version_id", app_version_id)
        pulumi.set(__self__, "cluster_id", cluster_id)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "group_id", group_id)
        pulumi.set(__self__, "group_name", group_name)
        pulumi.set(__self__, "group_type", group_type)
        pulumi.set(__self__, "package_version_id", package_version_id)
        pulumi.set(__self__, "update_time", update_time)

    @property
    @pulumi.getter(name="appId")
    def app_id(self) -> str:
        """
        ID of the EDAS application.
        """
        return pulumi.get(self, "app_id")

    @property
    @pulumi.getter(name="appVersionId")
    def app_version_id(self) -> str:
        """
        The version of the deployment package for the application.
        """
        return pulumi.get(self, "app_version_id")

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> str:
        """
        The ID of the cluster that you want to create the application.
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> int:
        """
        The time when the instance group was created.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> str:
        """
        The ID of the instance group.
        """
        return pulumi.get(self, "group_id")

    @property
    @pulumi.getter(name="groupName")
    def group_name(self) -> str:
        """
        The name of the instance group. The length cannot exceed 64 characters.
        """
        return pulumi.get(self, "group_name")

    @property
    @pulumi.getter(name="groupType")
    def group_type(self) -> int:
        """
        The type of the instance group. Valid values: 0: Default group. 1: Phased release is disabled for traffic management. 2: Phased release is enabled for traffic management.
        """
        return pulumi.get(self, "group_type")

    @property
    @pulumi.getter(name="packageVersionId")
    def package_version_id(self) -> str:
        """
        The version of the deployment package for the instance group that was created.
        """
        return pulumi.get(self, "package_version_id")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> int:
        """
        The time when the instance group was updated.
        """
        return pulumi.get(self, "update_time")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['InstanceArgs', 'Instance']

@pulumi.input_type
class InstanceArgs:
    def __init__(__self__, *,
                 payment_type: pulumi.Input[str],
                 period: pulumi.Input[int],
                 sd_cbool: pulumi.Input[str],
                 sdc: pulumi.Input[str],
                 sddp_version: pulumi.Input[str],
                 ud_cbool: pulumi.Input[str],
                 udc: pulumi.Input[str],
                 dataphin: Optional[pulumi.Input[str]] = None,
                 dataphin_count: Optional[pulumi.Input[str]] = None,
                 logistics: Optional[pulumi.Input[str]] = None,
                 modify_type: Optional[pulumi.Input[str]] = None,
                 renew_period: Optional[pulumi.Input[int]] = None,
                 renewal_status: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Instance resource.
        :param pulumi.Input[str] payment_type: The payment type of the resource. Valid values: `Subscription`.
        :param pulumi.Input[int] period: The Prepaid period. Valid values: `1`, `2`, `3`, `6`,`12`,`24`.
        :param pulumi.Input[str] sd_cbool: Whether to use the database. Valid values:`yes`,`no`.
        :param pulumi.Input[str] sdc: The number of instances.
        :param pulumi.Input[str] sddp_version: The sddp version. Valid values: `version_audit`,`version_company`,`version_dlp`.
        :param pulumi.Input[str] ud_cbool: Whether to use OSS. Valid values: `yes`,`no`.
        :param pulumi.Input[str] udc: OSS Size.
        :param pulumi.Input[str] dataphin: The dataphin. Valid values: `yes`,`no`.
        :param pulumi.Input[str] dataphin_count: The dataphin count. Valid values: 1 to 20.
        :param pulumi.Input[str] logistics: The logistics.
        :param pulumi.Input[str] modify_type: The modify type. Valid values: `Upgrade`, `Downgrade`.  **NOTE:** The `modify_type` is required when you execute a update operation.
        :param pulumi.Input[int] renew_period: Automatic renewal period. **NOTE:** The `renew_period` is required under the condition that renewal_status is `AutoRenewal`,
        :param pulumi.Input[str] renewal_status: Automatic renewal status. Valid values: `AutoRenewal`,`ManualRenewal`. Default Value: `ManualRenewal`.
        """
        pulumi.set(__self__, "payment_type", payment_type)
        pulumi.set(__self__, "period", period)
        pulumi.set(__self__, "sd_cbool", sd_cbool)
        pulumi.set(__self__, "sdc", sdc)
        pulumi.set(__self__, "sddp_version", sddp_version)
        pulumi.set(__self__, "ud_cbool", ud_cbool)
        pulumi.set(__self__, "udc", udc)
        if dataphin is not None:
            pulumi.set(__self__, "dataphin", dataphin)
        if dataphin_count is not None:
            pulumi.set(__self__, "dataphin_count", dataphin_count)
        if logistics is not None:
            pulumi.set(__self__, "logistics", logistics)
        if modify_type is not None:
            pulumi.set(__self__, "modify_type", modify_type)
        if renew_period is not None:
            pulumi.set(__self__, "renew_period", renew_period)
        if renewal_status is not None:
            pulumi.set(__self__, "renewal_status", renewal_status)

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> pulumi.Input[str]:
        """
        The payment type of the resource. Valid values: `Subscription`.
        """
        return pulumi.get(self, "payment_type")

    @payment_type.setter
    def payment_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "payment_type", value)

    @property
    @pulumi.getter
    def period(self) -> pulumi.Input[int]:
        """
        The Prepaid period. Valid values: `1`, `2`, `3`, `6`,`12`,`24`.
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: pulumi.Input[int]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="sdCbool")
    def sd_cbool(self) -> pulumi.Input[str]:
        """
        Whether to use the database. Valid values:`yes`,`no`.
        """
        return pulumi.get(self, "sd_cbool")

    @sd_cbool.setter
    def sd_cbool(self, value: pulumi.Input[str]):
        pulumi.set(self, "sd_cbool", value)

    @property
    @pulumi.getter
    def sdc(self) -> pulumi.Input[str]:
        """
        The number of instances.
        """
        return pulumi.get(self, "sdc")

    @sdc.setter
    def sdc(self, value: pulumi.Input[str]):
        pulumi.set(self, "sdc", value)

    @property
    @pulumi.getter(name="sddpVersion")
    def sddp_version(self) -> pulumi.Input[str]:
        """
        The sddp version. Valid values: `version_audit`,`version_company`,`version_dlp`.
        """
        return pulumi.get(self, "sddp_version")

    @sddp_version.setter
    def sddp_version(self, value: pulumi.Input[str]):
        pulumi.set(self, "sddp_version", value)

    @property
    @pulumi.getter(name="udCbool")
    def ud_cbool(self) -> pulumi.Input[str]:
        """
        Whether to use OSS. Valid values: `yes`,`no`.
        """
        return pulumi.get(self, "ud_cbool")

    @ud_cbool.setter
    def ud_cbool(self, value: pulumi.Input[str]):
        pulumi.set(self, "ud_cbool", value)

    @property
    @pulumi.getter
    def udc(self) -> pulumi.Input[str]:
        """
        OSS Size.
        """
        return pulumi.get(self, "udc")

    @udc.setter
    def udc(self, value: pulumi.Input[str]):
        pulumi.set(self, "udc", value)

    @property
    @pulumi.getter
    def dataphin(self) -> Optional[pulumi.Input[str]]:
        """
        The dataphin. Valid values: `yes`,`no`.
        """
        return pulumi.get(self, "dataphin")

    @dataphin.setter
    def dataphin(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dataphin", value)

    @property
    @pulumi.getter(name="dataphinCount")
    def dataphin_count(self) -> Optional[pulumi.Input[str]]:
        """
        The dataphin count. Valid values: 1 to 20.
        """
        return pulumi.get(self, "dataphin_count")

    @dataphin_count.setter
    def dataphin_count(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dataphin_count", value)

    @property
    @pulumi.getter
    def logistics(self) -> Optional[pulumi.Input[str]]:
        """
        The logistics.
        """
        return pulumi.get(self, "logistics")

    @logistics.setter
    def logistics(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "logistics", value)

    @property
    @pulumi.getter(name="modifyType")
    def modify_type(self) -> Optional[pulumi.Input[str]]:
        """
        The modify type. Valid values: `Upgrade`, `Downgrade`.  **NOTE:** The `modify_type` is required when you execute a update operation.
        """
        return pulumi.get(self, "modify_type")

    @modify_type.setter
    def modify_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "modify_type", value)

    @property
    @pulumi.getter(name="renewPeriod")
    def renew_period(self) -> Optional[pulumi.Input[int]]:
        """
        Automatic renewal period. **NOTE:** The `renew_period` is required under the condition that renewal_status is `AutoRenewal`,
        """
        return pulumi.get(self, "renew_period")

    @renew_period.setter
    def renew_period(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "renew_period", value)

    @property
    @pulumi.getter(name="renewalStatus")
    def renewal_status(self) -> Optional[pulumi.Input[str]]:
        """
        Automatic renewal status. Valid values: `AutoRenewal`,`ManualRenewal`. Default Value: `ManualRenewal`.
        """
        return pulumi.get(self, "renewal_status")

    @renewal_status.setter
    def renewal_status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "renewal_status", value)


@pulumi.input_type
class _InstanceState:
    def __init__(__self__, *,
                 authed: Optional[pulumi.Input[bool]] = None,
                 dataphin: Optional[pulumi.Input[str]] = None,
                 dataphin_count: Optional[pulumi.Input[str]] = None,
                 instance_num: Optional[pulumi.Input[str]] = None,
                 logistics: Optional[pulumi.Input[str]] = None,
                 modify_type: Optional[pulumi.Input[str]] = None,
                 odps_set: Optional[pulumi.Input[bool]] = None,
                 oss_bucket_set: Optional[pulumi.Input[bool]] = None,
                 oss_size: Optional[pulumi.Input[str]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 rds_set: Optional[pulumi.Input[bool]] = None,
                 remain_days: Optional[pulumi.Input[str]] = None,
                 renew_period: Optional[pulumi.Input[int]] = None,
                 renewal_status: Optional[pulumi.Input[str]] = None,
                 sd_cbool: Optional[pulumi.Input[str]] = None,
                 sdc: Optional[pulumi.Input[str]] = None,
                 sddp_version: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 ud_cbool: Optional[pulumi.Input[str]] = None,
                 udc: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Instance resources.
        :param pulumi.Input[bool] authed: Whether the required RAM authorization is configured.
        :param pulumi.Input[str] dataphin: The dataphin. Valid values: `yes`,`no`.
        :param pulumi.Input[str] dataphin_count: The dataphin count. Valid values: 1 to 20.
        :param pulumi.Input[str] instance_num: The number of instances.
        :param pulumi.Input[str] logistics: The logistics.
        :param pulumi.Input[str] modify_type: The modify type. Valid values: `Upgrade`, `Downgrade`.  **NOTE:** The `modify_type` is required when you execute a update operation.
        :param pulumi.Input[bool] odps_set: Whether the authorized MaxCompute (ODPS) assets.
        :param pulumi.Input[bool] oss_bucket_set: Whether the authorized oss assets.
        :param pulumi.Input[str] payment_type: The payment type of the resource. Valid values: `Subscription`.
        :param pulumi.Input[int] period: The Prepaid period. Valid values: `1`, `2`, `3`, `6`,`12`,`24`.
        :param pulumi.Input[bool] rds_set: Whether the authorized rds assets.
        :param pulumi.Input[int] renew_period: Automatic renewal period. **NOTE:** The `renew_period` is required under the condition that renewal_status is `AutoRenewal`,
        :param pulumi.Input[str] renewal_status: Automatic renewal status. Valid values: `AutoRenewal`,`ManualRenewal`. Default Value: `ManualRenewal`.
        :param pulumi.Input[str] sd_cbool: Whether to use the database. Valid values:`yes`,`no`.
        :param pulumi.Input[str] sdc: The number of instances.
        :param pulumi.Input[str] sddp_version: The sddp version. Valid values: `version_audit`,`version_company`,`version_dlp`.
        :param pulumi.Input[str] status: The status of the resource.
        :param pulumi.Input[str] ud_cbool: Whether to use OSS. Valid values: `yes`,`no`.
        :param pulumi.Input[str] udc: OSS Size.
        """
        if authed is not None:
            pulumi.set(__self__, "authed", authed)
        if dataphin is not None:
            pulumi.set(__self__, "dataphin", dataphin)
        if dataphin_count is not None:
            pulumi.set(__self__, "dataphin_count", dataphin_count)
        if instance_num is not None:
            pulumi.set(__self__, "instance_num", instance_num)
        if logistics is not None:
            pulumi.set(__self__, "logistics", logistics)
        if modify_type is not None:
            pulumi.set(__self__, "modify_type", modify_type)
        if odps_set is not None:
            pulumi.set(__self__, "odps_set", odps_set)
        if oss_bucket_set is not None:
            pulumi.set(__self__, "oss_bucket_set", oss_bucket_set)
        if oss_size is not None:
            pulumi.set(__self__, "oss_size", oss_size)
        if payment_type is not None:
            pulumi.set(__self__, "payment_type", payment_type)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if rds_set is not None:
            pulumi.set(__self__, "rds_set", rds_set)
        if remain_days is not None:
            pulumi.set(__self__, "remain_days", remain_days)
        if renew_period is not None:
            pulumi.set(__self__, "renew_period", renew_period)
        if renewal_status is not None:
            pulumi.set(__self__, "renewal_status", renewal_status)
        if sd_cbool is not None:
            pulumi.set(__self__, "sd_cbool", sd_cbool)
        if sdc is not None:
            pulumi.set(__self__, "sdc", sdc)
        if sddp_version is not None:
            pulumi.set(__self__, "sddp_version", sddp_version)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if ud_cbool is not None:
            pulumi.set(__self__, "ud_cbool", ud_cbool)
        if udc is not None:
            pulumi.set(__self__, "udc", udc)

    @property
    @pulumi.getter
    def authed(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the required RAM authorization is configured.
        """
        return pulumi.get(self, "authed")

    @authed.setter
    def authed(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "authed", value)

    @property
    @pulumi.getter
    def dataphin(self) -> Optional[pulumi.Input[str]]:
        """
        The dataphin. Valid values: `yes`,`no`.
        """
        return pulumi.get(self, "dataphin")

    @dataphin.setter
    def dataphin(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dataphin", value)

    @property
    @pulumi.getter(name="dataphinCount")
    def dataphin_count(self) -> Optional[pulumi.Input[str]]:
        """
        The dataphin count. Valid values: 1 to 20.
        """
        return pulumi.get(self, "dataphin_count")

    @dataphin_count.setter
    def dataphin_count(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dataphin_count", value)

    @property
    @pulumi.getter(name="instanceNum")
    def instance_num(self) -> Optional[pulumi.Input[str]]:
        """
        The number of instances.
        """
        return pulumi.get(self, "instance_num")

    @instance_num.setter
    def instance_num(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_num", value)

    @property
    @pulumi.getter
    def logistics(self) -> Optional[pulumi.Input[str]]:
        """
        The logistics.
        """
        return pulumi.get(self, "logistics")

    @logistics.setter
    def logistics(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "logistics", value)

    @property
    @pulumi.getter(name="modifyType")
    def modify_type(self) -> Optional[pulumi.Input[str]]:
        """
        The modify type. Valid values: `Upgrade`, `Downgrade`.  **NOTE:** The `modify_type` is required when you execute a update operation.
        """
        return pulumi.get(self, "modify_type")

    @modify_type.setter
    def modify_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "modify_type", value)

    @property
    @pulumi.getter(name="odpsSet")
    def odps_set(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the authorized MaxCompute (ODPS) assets.
        """
        return pulumi.get(self, "odps_set")

    @odps_set.setter
    def odps_set(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "odps_set", value)

    @property
    @pulumi.getter(name="ossBucketSet")
    def oss_bucket_set(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the authorized oss assets.
        """
        return pulumi.get(self, "oss_bucket_set")

    @oss_bucket_set.setter
    def oss_bucket_set(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "oss_bucket_set", value)

    @property
    @pulumi.getter(name="ossSize")
    def oss_size(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "oss_size")

    @oss_size.setter
    def oss_size(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "oss_size", value)

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> Optional[pulumi.Input[str]]:
        """
        The payment type of the resource. Valid values: `Subscription`.
        """
        return pulumi.get(self, "payment_type")

    @payment_type.setter
    def payment_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "payment_type", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[int]]:
        """
        The Prepaid period. Valid values: `1`, `2`, `3`, `6`,`12`,`24`.
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="rdsSet")
    def rds_set(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the authorized rds assets.
        """
        return pulumi.get(self, "rds_set")

    @rds_set.setter
    def rds_set(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "rds_set", value)

    @property
    @pulumi.getter(name="remainDays")
    def remain_days(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "remain_days")

    @remain_days.setter
    def remain_days(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "remain_days", value)

    @property
    @pulumi.getter(name="renewPeriod")
    def renew_period(self) -> Optional[pulumi.Input[int]]:
        """
        Automatic renewal period. **NOTE:** The `renew_period` is required under the condition that renewal_status is `AutoRenewal`,
        """
        return pulumi.get(self, "renew_period")

    @renew_period.setter
    def renew_period(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "renew_period", value)

    @property
    @pulumi.getter(name="renewalStatus")
    def renewal_status(self) -> Optional[pulumi.Input[str]]:
        """
        Automatic renewal status. Valid values: `AutoRenewal`,`ManualRenewal`. Default Value: `ManualRenewal`.
        """
        return pulumi.get(self, "renewal_status")

    @renewal_status.setter
    def renewal_status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "renewal_status", value)

    @property
    @pulumi.getter(name="sdCbool")
    def sd_cbool(self) -> Optional[pulumi.Input[str]]:
        """
        Whether to use the database. Valid values:`yes`,`no`.
        """
        return pulumi.get(self, "sd_cbool")

    @sd_cbool.setter
    def sd_cbool(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sd_cbool", value)

    @property
    @pulumi.getter
    def sdc(self) -> Optional[pulumi.Input[str]]:
        """
        The number of instances.
        """
        return pulumi.get(self, "sdc")

    @sdc.setter
    def sdc(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sdc", value)

    @property
    @pulumi.getter(name="sddpVersion")
    def sddp_version(self) -> Optional[pulumi.Input[str]]:
        """
        The sddp version. Valid values: `version_audit`,`version_company`,`version_dlp`.
        """
        return pulumi.get(self, "sddp_version")

    @sddp_version.setter
    def sddp_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sddp_version", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the resource.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="udCbool")
    def ud_cbool(self) -> Optional[pulumi.Input[str]]:
        """
        Whether to use OSS. Valid values: `yes`,`no`.
        """
        return pulumi.get(self, "ud_cbool")

    @ud_cbool.setter
    def ud_cbool(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ud_cbool", value)

    @property
    @pulumi.getter
    def udc(self) -> Optional[pulumi.Input[str]]:
        """
        OSS Size.
        """
        return pulumi.get(self, "udc")

    @udc.setter
    def udc(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "udc", value)


class Instance(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dataphin: Optional[pulumi.Input[str]] = None,
                 dataphin_count: Optional[pulumi.Input[str]] = None,
                 logistics: Optional[pulumi.Input[str]] = None,
                 modify_type: Optional[pulumi.Input[str]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 renew_period: Optional[pulumi.Input[int]] = None,
                 renewal_status: Optional[pulumi.Input[str]] = None,
                 sd_cbool: Optional[pulumi.Input[str]] = None,
                 sdc: Optional[pulumi.Input[str]] = None,
                 sddp_version: Optional[pulumi.Input[str]] = None,
                 ud_cbool: Optional[pulumi.Input[str]] = None,
                 udc: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Data Security Center Instance resource.

        For information about Data Security Center Instance and how to use it, see [What is Instance](https://help.aliyun.com/product/88674.html).

        > **NOTE:** Available in v1.136.0+.

        > **NOTE:** The Data Security Center Instance is not support in the international site.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.sddp.Instance("default",
            dataphin="yes",
            payment_type="Subscription",
            period=1,
            sd_cbool="yes",
            sdc="3",
            sddp_version="version_company",
            ud_cbool="yes",
            udc="2000")
        ```

        ## Import

        Data Security Center Instance can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:sddp/instance:Instance example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] dataphin: The dataphin. Valid values: `yes`,`no`.
        :param pulumi.Input[str] dataphin_count: The dataphin count. Valid values: 1 to 20.
        :param pulumi.Input[str] logistics: The logistics.
        :param pulumi.Input[str] modify_type: The modify type. Valid values: `Upgrade`, `Downgrade`.  **NOTE:** The `modify_type` is required when you execute a update operation.
        :param pulumi.Input[str] payment_type: The payment type of the resource. Valid values: `Subscription`.
        :param pulumi.Input[int] period: The Prepaid period. Valid values: `1`, `2`, `3`, `6`,`12`,`24`.
        :param pulumi.Input[int] renew_period: Automatic renewal period. **NOTE:** The `renew_period` is required under the condition that renewal_status is `AutoRenewal`,
        :param pulumi.Input[str] renewal_status: Automatic renewal status. Valid values: `AutoRenewal`,`ManualRenewal`. Default Value: `ManualRenewal`.
        :param pulumi.Input[str] sd_cbool: Whether to use the database. Valid values:`yes`,`no`.
        :param pulumi.Input[str] sdc: The number of instances.
        :param pulumi.Input[str] sddp_version: The sddp version. Valid values: `version_audit`,`version_company`,`version_dlp`.
        :param pulumi.Input[str] ud_cbool: Whether to use OSS. Valid values: `yes`,`no`.
        :param pulumi.Input[str] udc: OSS Size.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InstanceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Data Security Center Instance resource.

        For information about Data Security Center Instance and how to use it, see [What is Instance](https://help.aliyun.com/product/88674.html).

        > **NOTE:** Available in v1.136.0+.

        > **NOTE:** The Data Security Center Instance is not support in the international site.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.sddp.Instance("default",
            dataphin="yes",
            payment_type="Subscription",
            period=1,
            sd_cbool="yes",
            sdc="3",
            sddp_version="version_company",
            ud_cbool="yes",
            udc="2000")
        ```

        ## Import

        Data Security Center Instance can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:sddp/instance:Instance example <id>
        ```

        :param str resource_name: The name of the resource.
        :param InstanceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InstanceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dataphin: Optional[pulumi.Input[str]] = None,
                 dataphin_count: Optional[pulumi.Input[str]] = None,
                 logistics: Optional[pulumi.Input[str]] = None,
                 modify_type: Optional[pulumi.Input[str]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 renew_period: Optional[pulumi.Input[int]] = None,
                 renewal_status: Optional[pulumi.Input[str]] = None,
                 sd_cbool: Optional[pulumi.Input[str]] = None,
                 sdc: Optional[pulumi.Input[str]] = None,
                 sddp_version: Optional[pulumi.Input[str]] = None,
                 ud_cbool: Optional[pulumi.Input[str]] = None,
                 udc: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InstanceArgs.__new__(InstanceArgs)

            __props__.__dict__["dataphin"] = dataphin
            __props__.__dict__["dataphin_count"] = dataphin_count
            __props__.__dict__["logistics"] = logistics
            __props__.__dict__["modify_type"] = modify_type
            if payment_type is None and not opts.urn:
                raise TypeError("Missing required property 'payment_type'")
            __props__.__dict__["payment_type"] = payment_type
            if period is None and not opts.urn:
                raise TypeError("Missing required property 'period'")
            __props__.__dict__["period"] = period
            __props__.__dict__["renew_period"] = renew_period
            __props__.__dict__["renewal_status"] = renewal_status
            if sd_cbool is None and not opts.urn:
                raise TypeError("Missing required property 'sd_cbool'")
            __props__.__dict__["sd_cbool"] = sd_cbool
            if sdc is None and not opts.urn:
                raise TypeError("Missing required property 'sdc'")
            __props__.__dict__["sdc"] = sdc
            if sddp_version is None and not opts.urn:
                raise TypeError("Missing required property 'sddp_version'")
            __props__.__dict__["sddp_version"] = sddp_version
            if ud_cbool is None and not opts.urn:
                raise TypeError("Missing required property 'ud_cbool'")
            __props__.__dict__["ud_cbool"] = ud_cbool
            if udc is None and not opts.urn:
                raise TypeError("Missing required property 'udc'")
            __props__.__dict__["udc"] = udc
            __props__.__dict__["authed"] = None
            __props__.__dict__["instance_num"] = None
            __props__.__dict__["odps_set"] = None
            __props__.__dict__["oss_bucket_set"] = None
            __props__.__dict__["oss_size"] = None
            __props__.__dict__["rds_set"] = None
            __props__.__dict__["remain_days"] = None
            __props__.__dict__["status"] = None
        super(Instance, __self__).__init__(
            'alicloud:sddp/instance:Instance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            authed: Optional[pulumi.Input[bool]] = None,
            dataphin: Optional[pulumi.Input[str]] = None,
            dataphin_count: Optional[pulumi.Input[str]] = None,
            instance_num: Optional[pulumi.Input[str]] = None,
            logistics: Optional[pulumi.Input[str]] = None,
            modify_type: Optional[pulumi.Input[str]] = None,
            odps_set: Optional[pulumi.Input[bool]] = None,
            oss_bucket_set: Optional[pulumi.Input[bool]] = None,
            oss_size: Optional[pulumi.Input[str]] = None,
            payment_type: Optional[pulumi.Input[str]] = None,
            period: Optional[pulumi.Input[int]] = None,
            rds_set: Optional[pulumi.Input[bool]] = None,
            remain_days: Optional[pulumi.Input[str]] = None,
            renew_period: Optional[pulumi.Input[int]] = None,
            renewal_status: Optional[pulumi.Input[str]] = None,
            sd_cbool: Optional[pulumi.Input[str]] = None,
            sdc: Optional[pulumi.Input[str]] = None,
            sddp_version: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            ud_cbool: Optional[pulumi.Input[str]] = None,
            udc: Optional[pulumi.Input[str]] = None) -> 'Instance':
        """
        Get an existing Instance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] authed: Whether the required RAM authorization is configured.
        :param pulumi.Input[str] dataphin: The dataphin. Valid values: `yes`,`no`.
        :param pulumi.Input[str] dataphin_count: The dataphin count. Valid values: 1 to 20.
        :param pulumi.Input[str] instance_num: The number of instances.
        :param pulumi.Input[str] logistics: The logistics.
        :param pulumi.Input[str] modify_type: The modify type. Valid values: `Upgrade`, `Downgrade`.  **NOTE:** The `modify_type` is required when you execute a update operation.
        :param pulumi.Input[bool] odps_set: Whether the authorized MaxCompute (ODPS) assets.
        :param pulumi.Input[bool] oss_bucket_set: Whether the authorized oss assets.
        :param pulumi.Input[str] payment_type: The payment type of the resource. Valid values: `Subscription`.
        :param pulumi.Input[int] period: The Prepaid period. Valid values: `1`, `2`, `3`, `6`,`12`,`24`.
        :param pulumi.Input[bool] rds_set: Whether the authorized rds assets.
        :param pulumi.Input[int] renew_period: Automatic renewal period. **NOTE:** The `renew_period` is required under the condition that renewal_status is `AutoRenewal`,
        :param pulumi.Input[str] renewal_status: Automatic renewal status. Valid values: `AutoRenewal`,`ManualRenewal`. Default Value: `ManualRenewal`.
        :param pulumi.Input[str] sd_cbool: Whether to use the database. Valid values:`yes`,`no`.
        :param pulumi.Input[str] sdc: The number of instances.
        :param pulumi.Input[str] sddp_version: The sddp version. Valid values: `version_audit`,`version_company`,`version_dlp`.
        :param pulumi.Input[str] status: The status of the resource.
        :param pulumi.Input[str] ud_cbool: Whether to use OSS. Valid values: `yes`,`no`.
        :param pulumi.Input[str] udc: OSS Size.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InstanceState.__new__(_InstanceState)

        __props__.__dict__["authed"] = authed
        __props__.__dict__["dataphin"] = dataphin
        __props__.__dict__["dataphin_count"] = dataphin_count
        __props__.__dict__["instance_num"] = instance_num
        __props__.__dict__["logistics"] = logistics
        __props__.__dict__["modify_type"] = modify_type
        __props__.__dict__["odps_set"] = odps_set
        __props__.__dict__["oss_bucket_set"] = oss_bucket_set
        __props__.__dict__["oss_size"] = oss_size
        __props__.__dict__["payment_type"] = payment_type
        __props__.__dict__["period"] = period
        __props__.__dict__["rds_set"] = rds_set
        __props__.__dict__["remain_days"] = remain_days
        __props__.__dict__["renew_period"] = renew_period
        __props__.__dict__["renewal_status"] = renewal_status
        __props__.__dict__["sd_cbool"] = sd_cbool
        __props__.__dict__["sdc"] = sdc
        __props__.__dict__["sddp_version"] = sddp_version
        __props__.__dict__["status"] = status
        __props__.__dict__["ud_cbool"] = ud_cbool
        __props__.__dict__["udc"] = udc
        return Instance(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def authed(self) -> pulumi.Output[bool]:
        """
        Whether the required RAM authorization is configured.
        """
        return pulumi.get(self, "authed")

    @property
    @pulumi.getter
    def dataphin(self) -> pulumi.Output[Optional[str]]:
        """
        The dataphin. Valid values: `yes`,`no`.
        """
        return pulumi.get(self, "dataphin")

    @property
    @pulumi.getter(name="dataphinCount")
    def dataphin_count(self) -> pulumi.Output[Optional[str]]:
        """
        The dataphin count. Valid values: 1 to 20.
        """
        return pulumi.get(self, "dataphin_count")

    @property
    @pulumi.getter(name="instanceNum")
    def instance_num(self) -> pulumi.Output[str]:
        """
        The number of instances.
        """
        return pulumi.get(self, "instance_num")

    @property
    @pulumi.getter
    def logistics(self) -> pulumi.Output[Optional[str]]:
        """
        The logistics.
        """
        return pulumi.get(self, "logistics")

    @property
    @pulumi.getter(name="modifyType")
    def modify_type(self) -> pulumi.Output[Optional[str]]:
        """
        The modify type. Valid values: `Upgrade`, `Downgrade`.  **NOTE:** The `modify_type` is required when you execute a update operation.
        """
        return pulumi.get(self, "modify_type")

    @property
    @pulumi.getter(name="odpsSet")
    def odps_set(self) -> pulumi.Output[bool]:
        """
        Whether the authorized MaxCompute (ODPS) assets.
        """
        return pulumi.get(self, "odps_set")

    @property
    @pulumi.getter(name="ossBucketSet")
    def oss_bucket_set(self) -> pulumi.Output[bool]:
        """
        Whether the authorized oss assets.
        """
        return pulumi.get(self, "oss_bucket_set")

    @property
    @pulumi.getter(name="ossSize")
    def oss_size(self) -> pulumi.Output[str]:
        return pulumi.get(self, "oss_size")

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> pulumi.Output[str]:
        """
        The payment type of the resource. Valid values: `Subscription`.
        """
        return pulumi.get(self, "payment_type")

    @property
    @pulumi.getter
    def period(self) -> pulumi.Output[int]:
        """
        The Prepaid period. Valid values: `1`, `2`, `3`, `6`,`12`,`24`.
        """
        return pulumi.get(self, "period")

    @property
    @pulumi.getter(name="rdsSet")
    def rds_set(self) -> pulumi.Output[bool]:
        """
        Whether the authorized rds assets.
        """
        return pulumi.get(self, "rds_set")

    @property
    @pulumi.getter(name="remainDays")
    def remain_days(self) -> pulumi.Output[str]:
        return pulumi.get(self, "remain_days")

    @property
    @pulumi.getter(name="renewPeriod")
    def renew_period(self) -> pulumi.Output[Optional[int]]:
        """
        Automatic renewal period. **NOTE:** The `renew_period` is required under the condition that renewal_status is `AutoRenewal`,
        """
        return pulumi.get(self, "renew_period")

    @property
    @pulumi.getter(name="renewalStatus")
    def renewal_status(self) -> pulumi.Output[str]:
        """
        Automatic renewal status. Valid values: `AutoRenewal`,`ManualRenewal`. Default Value: `ManualRenewal`.
        """
        return pulumi.get(self, "renewal_status")

    @property
    @pulumi.getter(name="sdCbool")
    def sd_cbool(self) -> pulumi.Output[str]:
        """
        Whether to use the database. Valid values:`yes`,`no`.
        """
        return pulumi.get(self, "sd_cbool")

    @property
    @pulumi.getter
    def sdc(self) -> pulumi.Output[str]:
        """
        The number of instances.
        """
        return pulumi.get(self, "sdc")

    @property
    @pulumi.getter(name="sddpVersion")
    def sddp_version(self) -> pulumi.Output[str]:
        """
        The sddp version. Valid values: `version_audit`,`version_company`,`version_dlp`.
        """
        return pulumi.get(self, "sddp_version")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the resource.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="udCbool")
    def ud_cbool(self) -> pulumi.Output[str]:
        """
        Whether to use OSS. Valid values: `yes`,`no`.
        """
        return pulumi.get(self, "ud_cbool")

    @property
    @pulumi.getter
    def udc(self) -> pulumi.Output[str]:
        """
        OSS Size.
        """
        return pulumi.get(self, "udc")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetTrafficMirrorServiceResult',
    'AwaitableGetTrafficMirrorServiceResult',
    'get_traffic_mirror_service',
    'get_traffic_mirror_service_output',
]

@pulumi.output_type
class GetTrafficMirrorServiceResult:
    """
    A collection of values returned by getTrafficMirrorService.
    """
    def __init__(__self__, enable=None, id=None, status=None):
        if enable and not isinstance(enable, str):
            raise TypeError("Expected argument 'enable' to be a str")
        pulumi.set(__self__, "enable", enable)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def enable(self) -> Optional[str]:
        return pulumi.get(self, "enable")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The current service enable status.
        """
        return pulumi.get(self, "status")


class AwaitableGetTrafficMirrorServiceResult(GetTrafficMirrorServiceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTrafficMirrorServiceResult(
            enable=self.enable,
            id=self.id,
            status=self.status)


def get_traffic_mirror_service(enable: Optional[str] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTrafficMirrorServiceResult:
    """
    Using this data source can open VPC Traffic Mirror service automatically. If the service has been opened, it will return opened.

    For information about VPC Traffic Mirror and how to use it, see [What is VPC Traffic Mirror](https://www.alibabacloud.com/help/en/doc-detail/207513.htm).

    > **NOTE:** Available in v1.141.0+

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    open = alicloud.vpc.get_traffic_mirror_service(enable="On")
    ```


    :param str enable: Setting the value to `On` to enable the service. If has been enabled, return the result. Valid values: `On` or `Off`. Default to `Off`.
    """
    __args__ = dict()
    __args__['enable'] = enable
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = _utilities.get_version()
    __ret__ = pulumi.runtime.invoke('alicloud:vpc/getTrafficMirrorService:getTrafficMirrorService', __args__, opts=opts, typ=GetTrafficMirrorServiceResult).value

    return AwaitableGetTrafficMirrorServiceResult(
        enable=__ret__.enable,
        id=__ret__.id,
        status=__ret__.status)


@_utilities.lift_output_func(get_traffic_mirror_service)
def get_traffic_mirror_service_output(enable: Optional[pulumi.Input[Optional[str]]] = None,
                                      opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetTrafficMirrorServiceResult]:
    """
    Using this data source can open VPC Traffic Mirror service automatically. If the service has been opened, it will return opened.

    For information about VPC Traffic Mirror and how to use it, see [What is VPC Traffic Mirror](https://www.alibabacloud.com/help/en/doc-detail/207513.htm).

    > **NOTE:** Available in v1.141.0+

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    open = alicloud.vpc.get_traffic_mirror_service(enable="On")
    ```


    :param str enable: Setting the value to `On` to enable the service. If has been enabled, return the result. Valid values: `On` or `Off`. Default to `Off`.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['EcsPrefixListArgs', 'EcsPrefixList']

@pulumi.input_type
class EcsPrefixListArgs:
    def __init__(__self__, *,
                 address_family: pulumi.Input[str],
                 entries: pulumi.Input[Sequence[pulumi.Input['EcsPrefixListEntryArgs']]],
                 max_entries: pulumi.Input[int],
                 prefix_list_name: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a EcsPrefixList resource.
        :param pulumi.Input[str] address_family: The IP address family. Valid values: `IPv4`,`IPv6`.
        :param pulumi.Input[Sequence[pulumi.Input['EcsPrefixListEntryArgs']]] entries: The Entry. The details see Block `entry`.
        :param pulumi.Input[int] max_entries: The maximum number of entries that the prefix list can contain.  Valid values: 1 to 200.
        :param pulumi.Input[str] prefix_list_name: The name of the prefix. The name must be 2 to 128 characters in length. It must start with a letter and cannot start with `http://`, `https://`, `com.aliyun`, or `com.alibabacloud`. It can contain letters, digits, colons (:), underscores (_), periods (.), and hyphens (-).
        :param pulumi.Input[str] description: The description in entry. The description must be 2 to 32 characters in length and cannot start with `http://` or `https://`.
        """
        pulumi.set(__self__, "address_family", address_family)
        pulumi.set(__self__, "entries", entries)
        pulumi.set(__self__, "max_entries", max_entries)
        pulumi.set(__self__, "prefix_list_name", prefix_list_name)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @property
    @pulumi.getter(name="addressFamily")
    def address_family(self) -> pulumi.Input[str]:
        """
        The IP address family. Valid values: `IPv4`,`IPv6`.
        """
        return pulumi.get(self, "address_family")

    @address_family.setter
    def address_family(self, value: pulumi.Input[str]):
        pulumi.set(self, "address_family", value)

    @property
    @pulumi.getter
    def entries(self) -> pulumi.Input[Sequence[pulumi.Input['EcsPrefixListEntryArgs']]]:
        """
        The Entry. The details see Block `entry`.
        """
        return pulumi.get(self, "entries")

    @entries.setter
    def entries(self, value: pulumi.Input[Sequence[pulumi.Input['EcsPrefixListEntryArgs']]]):
        pulumi.set(self, "entries", value)

    @property
    @pulumi.getter(name="maxEntries")
    def max_entries(self) -> pulumi.Input[int]:
        """
        The maximum number of entries that the prefix list can contain.  Valid values: 1 to 200.
        """
        return pulumi.get(self, "max_entries")

    @max_entries.setter
    def max_entries(self, value: pulumi.Input[int]):
        pulumi.set(self, "max_entries", value)

    @property
    @pulumi.getter(name="prefixListName")
    def prefix_list_name(self) -> pulumi.Input[str]:
        """
        The name of the prefix. The name must be 2 to 128 characters in length. It must start with a letter and cannot start with `http://`, `https://`, `com.aliyun`, or `com.alibabacloud`. It can contain letters, digits, colons (:), underscores (_), periods (.), and hyphens (-).
        """
        return pulumi.get(self, "prefix_list_name")

    @prefix_list_name.setter
    def prefix_list_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "prefix_list_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description in entry. The description must be 2 to 32 characters in length and cannot start with `http://` or `https://`.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)


@pulumi.input_type
class _EcsPrefixListState:
    def __init__(__self__, *,
                 address_family: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 entries: Optional[pulumi.Input[Sequence[pulumi.Input['EcsPrefixListEntryArgs']]]] = None,
                 max_entries: Optional[pulumi.Input[int]] = None,
                 prefix_list_name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering EcsPrefixList resources.
        :param pulumi.Input[str] address_family: The IP address family. Valid values: `IPv4`,`IPv6`.
        :param pulumi.Input[str] description: The description in entry. The description must be 2 to 32 characters in length and cannot start with `http://` or `https://`.
        :param pulumi.Input[Sequence[pulumi.Input['EcsPrefixListEntryArgs']]] entries: The Entry. The details see Block `entry`.
        :param pulumi.Input[int] max_entries: The maximum number of entries that the prefix list can contain.  Valid values: 1 to 200.
        :param pulumi.Input[str] prefix_list_name: The name of the prefix. The name must be 2 to 128 characters in length. It must start with a letter and cannot start with `http://`, `https://`, `com.aliyun`, or `com.alibabacloud`. It can contain letters, digits, colons (:), underscores (_), periods (.), and hyphens (-).
        """
        if address_family is not None:
            pulumi.set(__self__, "address_family", address_family)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if entries is not None:
            pulumi.set(__self__, "entries", entries)
        if max_entries is not None:
            pulumi.set(__self__, "max_entries", max_entries)
        if prefix_list_name is not None:
            pulumi.set(__self__, "prefix_list_name", prefix_list_name)

    @property
    @pulumi.getter(name="addressFamily")
    def address_family(self) -> Optional[pulumi.Input[str]]:
        """
        The IP address family. Valid values: `IPv4`,`IPv6`.
        """
        return pulumi.get(self, "address_family")

    @address_family.setter
    def address_family(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "address_family", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description in entry. The description must be 2 to 32 characters in length and cannot start with `http://` or `https://`.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def entries(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EcsPrefixListEntryArgs']]]]:
        """
        The Entry. The details see Block `entry`.
        """
        return pulumi.get(self, "entries")

    @entries.setter
    def entries(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EcsPrefixListEntryArgs']]]]):
        pulumi.set(self, "entries", value)

    @property
    @pulumi.getter(name="maxEntries")
    def max_entries(self) -> Optional[pulumi.Input[int]]:
        """
        The maximum number of entries that the prefix list can contain.  Valid values: 1 to 200.
        """
        return pulumi.get(self, "max_entries")

    @max_entries.setter
    def max_entries(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_entries", value)

    @property
    @pulumi.getter(name="prefixListName")
    def prefix_list_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the prefix. The name must be 2 to 128 characters in length. It must start with a letter and cannot start with `http://`, `https://`, `com.aliyun`, or `com.alibabacloud`. It can contain letters, digits, colons (:), underscores (_), periods (.), and hyphens (-).
        """
        return pulumi.get(self, "prefix_list_name")

    @prefix_list_name.setter
    def prefix_list_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "prefix_list_name", value)


class EcsPrefixList(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 address_family: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 entries: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EcsPrefixListEntryArgs']]]]] = None,
                 max_entries: Optional[pulumi.Input[int]] = None,
                 prefix_list_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a ECS Prefix List resource.

        For information about ECS Prefix List and how to use it, see [What is Prefix List.](https://www.alibabacloud.com/help/en/doc-detail/207969.html).

        > **NOTE:** Available in v1.152.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.ecs.EcsPrefixList("default",
            address_family="IPv4",
            description="description",
            entries=[alicloud.ecs.EcsPrefixListEntryArgs(
                cidr="192.168.0.0/24",
                description="description",
            )],
            max_entries=2,
            prefix_list_name="tftest")
        ```

        ## Import

        ECS Prefix List can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:ecs/ecsPrefixList:EcsPrefixList example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] address_family: The IP address family. Valid values: `IPv4`,`IPv6`.
        :param pulumi.Input[str] description: The description in entry. The description must be 2 to 32 characters in length and cannot start with `http://` or `https://`.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EcsPrefixListEntryArgs']]]] entries: The Entry. The details see Block `entry`.
        :param pulumi.Input[int] max_entries: The maximum number of entries that the prefix list can contain.  Valid values: 1 to 200.
        :param pulumi.Input[str] prefix_list_name: The name of the prefix. The name must be 2 to 128 characters in length. It must start with a letter and cannot start with `http://`, `https://`, `com.aliyun`, or `com.alibabacloud`. It can contain letters, digits, colons (:), underscores (_), periods (.), and hyphens (-).
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EcsPrefixListArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a ECS Prefix List resource.

        For information about ECS Prefix List and how to use it, see [What is Prefix List.](https://www.alibabacloud.com/help/en/doc-detail/207969.html).

        > **NOTE:** Available in v1.152.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.ecs.EcsPrefixList("default",
            address_family="IPv4",
            description="description",
            entries=[alicloud.ecs.EcsPrefixListEntryArgs(
                cidr="192.168.0.0/24",
                description="description",
            )],
            max_entries=2,
            prefix_list_name="tftest")
        ```

        ## Import

        ECS Prefix List can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:ecs/ecsPrefixList:EcsPrefixList example <id>
        ```

        :param str resource_name: The name of the resource.
        :param EcsPrefixListArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EcsPrefixListArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 address_family: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 entries: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EcsPrefixListEntryArgs']]]]] = None,
                 max_entries: Optional[pulumi.Input[int]] = None,
                 prefix_list_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EcsPrefixListArgs.__new__(EcsPrefixListArgs)

            if address_family is None and not opts.urn:
                raise TypeError("Missing required property 'address_family'")
            __props__.__dict__["address_family"] = address_family
            __props__.__dict__["description"] = description
            if entries is None and not opts.urn:
                raise TypeError("Missing required property 'entries'")
            __props__.__dict__["entries"] = entries
            if max_entries is None and not opts.urn:
                raise TypeError("Missing required property 'max_entries'")
            __props__.__dict__["max_entries"] = max_entries
            if prefix_list_name is None and not opts.urn:
                raise TypeError("Missing required property 'prefix_list_name'")
            __props__.__dict__["prefix_list_name"] = prefix_list_name
        super(EcsPrefixList, __self__).__init__(
            'alicloud:ecs/ecsPrefixList:EcsPrefixList',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            address_family: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            entries: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EcsPrefixListEntryArgs']]]]] = None,
            max_entries: Optional[pulumi.Input[int]] = None,
            prefix_list_name: Optional[pulumi.Input[str]] = None) -> 'EcsPrefixList':
        """
        Get an existing EcsPrefixList resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] address_family: The IP address family. Valid values: `IPv4`,`IPv6`.
        :param pulumi.Input[str] description: The description in entry. The description must be 2 to 32 characters in length and cannot start with `http://` or `https://`.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EcsPrefixListEntryArgs']]]] entries: The Entry. The details see Block `entry`.
        :param pulumi.Input[int] max_entries: The maximum number of entries that the prefix list can contain.  Valid values: 1 to 200.
        :param pulumi.Input[str] prefix_list_name: The name of the prefix. The name must be 2 to 128 characters in length. It must start with a letter and cannot start with `http://`, `https://`, `com.aliyun`, or `com.alibabacloud`. It can contain letters, digits, colons (:), underscores (_), periods (.), and hyphens (-).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EcsPrefixListState.__new__(_EcsPrefixListState)

        __props__.__dict__["address_family"] = address_family
        __props__.__dict__["description"] = description
        __props__.__dict__["entries"] = entries
        __props__.__dict__["max_entries"] = max_entries
        __props__.__dict__["prefix_list_name"] = prefix_list_name
        return EcsPrefixList(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="addressFamily")
    def address_family(self) -> pulumi.Output[str]:
        """
        The IP address family. Valid values: `IPv4`,`IPv6`.
        """
        return pulumi.get(self, "address_family")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        The description in entry. The description must be 2 to 32 characters in length and cannot start with `http://` or `https://`.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def entries(self) -> pulumi.Output[Sequence['outputs.EcsPrefixListEntry']]:
        """
        The Entry. The details see Block `entry`.
        """
        return pulumi.get(self, "entries")

    @property
    @pulumi.getter(name="maxEntries")
    def max_entries(self) -> pulumi.Output[int]:
        """
        The maximum number of entries that the prefix list can contain.  Valid values: 1 to 200.
        """
        return pulumi.get(self, "max_entries")

    @property
    @pulumi.getter(name="prefixListName")
    def prefix_list_name(self) -> pulumi.Output[str]:
        """
        The name of the prefix. The name must be 2 to 128 characters in length. It must start with a letter and cannot start with `http://`, `https://`, `com.aliyun`, or `com.alibabacloud`. It can contain letters, digits, colons (:), underscores (_), periods (.), and hyphens (-).
        """
        return pulumi.get(self, "prefix_list_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['LoginProfileArgs', 'LoginProfile']

@pulumi.input_type
class LoginProfileArgs:
    def __init__(__self__, *,
                 password: pulumi.Input[str],
                 user_name: pulumi.Input[str],
                 mfa_bind_required: Optional[pulumi.Input[bool]] = None,
                 password_reset_required: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a LoginProfile resource.
        :param pulumi.Input[str] password: Password of the RAM user.
        :param pulumi.Input[str] user_name: Name of the RAM user. This name can have a string of 1 to 64 characters, must contain only alphanumeric characters or hyphens, such as "-",".","_", and must not begin with a hyphen.
        :param pulumi.Input[bool] mfa_bind_required: This parameter indicates whether the MFA needs to be bind when the user first logs in. Default value is `false`.
        :param pulumi.Input[bool] password_reset_required: This parameter indicates whether the password needs to be reset when the user first logs in. Default value is `false`.
        """
        pulumi.set(__self__, "password", password)
        pulumi.set(__self__, "user_name", user_name)
        if mfa_bind_required is not None:
            pulumi.set(__self__, "mfa_bind_required", mfa_bind_required)
        if password_reset_required is not None:
            pulumi.set(__self__, "password_reset_required", password_reset_required)

    @property
    @pulumi.getter
    def password(self) -> pulumi.Input[str]:
        """
        Password of the RAM user.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: pulumi.Input[str]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> pulumi.Input[str]:
        """
        Name of the RAM user. This name can have a string of 1 to 64 characters, must contain only alphanumeric characters or hyphens, such as "-",".","_", and must not begin with a hyphen.
        """
        return pulumi.get(self, "user_name")

    @user_name.setter
    def user_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "user_name", value)

    @property
    @pulumi.getter(name="mfaBindRequired")
    def mfa_bind_required(self) -> Optional[pulumi.Input[bool]]:
        """
        This parameter indicates whether the MFA needs to be bind when the user first logs in. Default value is `false`.
        """
        return pulumi.get(self, "mfa_bind_required")

    @mfa_bind_required.setter
    def mfa_bind_required(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "mfa_bind_required", value)

    @property
    @pulumi.getter(name="passwordResetRequired")
    def password_reset_required(self) -> Optional[pulumi.Input[bool]]:
        """
        This parameter indicates whether the password needs to be reset when the user first logs in. Default value is `false`.
        """
        return pulumi.get(self, "password_reset_required")

    @password_reset_required.setter
    def password_reset_required(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "password_reset_required", value)


@pulumi.input_type
class _LoginProfileState:
    def __init__(__self__, *,
                 mfa_bind_required: Optional[pulumi.Input[bool]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 password_reset_required: Optional[pulumi.Input[bool]] = None,
                 user_name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering LoginProfile resources.
        :param pulumi.Input[bool] mfa_bind_required: This parameter indicates whether the MFA needs to be bind when the user first logs in. Default value is `false`.
        :param pulumi.Input[str] password: Password of the RAM user.
        :param pulumi.Input[bool] password_reset_required: This parameter indicates whether the password needs to be reset when the user first logs in. Default value is `false`.
        :param pulumi.Input[str] user_name: Name of the RAM user. This name can have a string of 1 to 64 characters, must contain only alphanumeric characters or hyphens, such as "-",".","_", and must not begin with a hyphen.
        """
        if mfa_bind_required is not None:
            pulumi.set(__self__, "mfa_bind_required", mfa_bind_required)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if password_reset_required is not None:
            pulumi.set(__self__, "password_reset_required", password_reset_required)
        if user_name is not None:
            pulumi.set(__self__, "user_name", user_name)

    @property
    @pulumi.getter(name="mfaBindRequired")
    def mfa_bind_required(self) -> Optional[pulumi.Input[bool]]:
        """
        This parameter indicates whether the MFA needs to be bind when the user first logs in. Default value is `false`.
        """
        return pulumi.get(self, "mfa_bind_required")

    @mfa_bind_required.setter
    def mfa_bind_required(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "mfa_bind_required", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[str]]:
        """
        Password of the RAM user.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="passwordResetRequired")
    def password_reset_required(self) -> Optional[pulumi.Input[bool]]:
        """
        This parameter indicates whether the password needs to be reset when the user first logs in. Default value is `false`.
        """
        return pulumi.get(self, "password_reset_required")

    @password_reset_required.setter
    def password_reset_required(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "password_reset_required", value)

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the RAM user. This name can have a string of 1 to 64 characters, must contain only alphanumeric characters or hyphens, such as "-",".","_", and must not begin with a hyphen.
        """
        return pulumi.get(self, "user_name")

    @user_name.setter
    def user_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_name", value)


class LoginProfile(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 mfa_bind_required: Optional[pulumi.Input[bool]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 password_reset_required: Optional[pulumi.Input[bool]] = None,
                 user_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a RAM User Login Profile resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        # Create a RAM login profile.
        user = alicloud.ram.User("user",
            display_name="user_display_name",
            mobile="86-18688888888",
            email="hello.uuu@aaa.com",
            comments="yoyoyo",
            force=True)
        profile = alicloud.ram.LoginProfile("profile",
            user_name=user.name,
            password="Yourpassword1234")
        ```

        ## Import

        RAM login profile can be imported using the id or user name, e.g.

        ```sh
         $ pulumi import alicloud:ram/loginProfile:LoginProfile example my-login
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] mfa_bind_required: This parameter indicates whether the MFA needs to be bind when the user first logs in. Default value is `false`.
        :param pulumi.Input[str] password: Password of the RAM user.
        :param pulumi.Input[bool] password_reset_required: This parameter indicates whether the password needs to be reset when the user first logs in. Default value is `false`.
        :param pulumi.Input[str] user_name: Name of the RAM user. This name can have a string of 1 to 64 characters, must contain only alphanumeric characters or hyphens, such as "-",".","_", and must not begin with a hyphen.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: LoginProfileArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a RAM User Login Profile resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        # Create a RAM login profile.
        user = alicloud.ram.User("user",
            display_name="user_display_name",
            mobile="86-18688888888",
            email="hello.uuu@aaa.com",
            comments="yoyoyo",
            force=True)
        profile = alicloud.ram.LoginProfile("profile",
            user_name=user.name,
            password="Yourpassword1234")
        ```

        ## Import

        RAM login profile can be imported using the id or user name, e.g.

        ```sh
         $ pulumi import alicloud:ram/loginProfile:LoginProfile example my-login
        ```

        :param str resource_name: The name of the resource.
        :param LoginProfileArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(LoginProfileArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 mfa_bind_required: Optional[pulumi.Input[bool]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 password_reset_required: Optional[pulumi.Input[bool]] = None,
                 user_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = LoginProfileArgs.__new__(LoginProfileArgs)

            __props__.__dict__["mfa_bind_required"] = mfa_bind_required
            if password is None and not opts.urn:
                raise TypeError("Missing required property 'password'")
            __props__.__dict__["password"] = password
            __props__.__dict__["password_reset_required"] = password_reset_required
            if user_name is None and not opts.urn:
                raise TypeError("Missing required property 'user_name'")
            __props__.__dict__["user_name"] = user_name
        super(LoginProfile, __self__).__init__(
            'alicloud:ram/loginProfile:LoginProfile',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            mfa_bind_required: Optional[pulumi.Input[bool]] = None,
            password: Optional[pulumi.Input[str]] = None,
            password_reset_required: Optional[pulumi.Input[bool]] = None,
            user_name: Optional[pulumi.Input[str]] = None) -> 'LoginProfile':
        """
        Get an existing LoginProfile resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] mfa_bind_required: This parameter indicates whether the MFA needs to be bind when the user first logs in. Default value is `false`.
        :param pulumi.Input[str] password: Password of the RAM user.
        :param pulumi.Input[bool] password_reset_required: This parameter indicates whether the password needs to be reset when the user first logs in. Default value is `false`.
        :param pulumi.Input[str] user_name: Name of the RAM user. This name can have a string of 1 to 64 characters, must contain only alphanumeric characters or hyphens, such as "-",".","_", and must not begin with a hyphen.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _LoginProfileState.__new__(_LoginProfileState)

        __props__.__dict__["mfa_bind_required"] = mfa_bind_required
        __props__.__dict__["password"] = password
        __props__.__dict__["password_reset_required"] = password_reset_required
        __props__.__dict__["user_name"] = user_name
        return LoginProfile(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="mfaBindRequired")
    def mfa_bind_required(self) -> pulumi.Output[Optional[bool]]:
        """
        This parameter indicates whether the MFA needs to be bind when the user first logs in. Default value is `false`.
        """
        return pulumi.get(self, "mfa_bind_required")

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[str]:
        """
        Password of the RAM user.
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="passwordResetRequired")
    def password_reset_required(self) -> pulumi.Output[Optional[bool]]:
        """
        This parameter indicates whether the password needs to be reset when the user first logs in. Default value is `false`.
        """
        return pulumi.get(self, "password_reset_required")

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> pulumi.Output[str]:
        """
        Name of the RAM user. This name can have a string of 1 to 64 characters, must contain only alphanumeric characters or hyphens, such as "-",".","_", and must not begin with a hyphen.
        """
        return pulumi.get(self, "user_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['ServiceLinkedRoleArgs', 'ServiceLinkedRole']

@pulumi.input_type
class ServiceLinkedRoleArgs:
    def __init__(__self__):
        """
        The set of arguments for constructing a ServiceLinkedRole resource.
        """
        pass


@pulumi.input_type
class _ServiceLinkedRoleState:
    def __init__(__self__, *,
                 status: Optional[pulumi.Input[bool]] = None):
        """
        Input properties used for looking up and filtering ServiceLinkedRole resources.
        :param pulumi.Input[bool] status: The status of the service Associated role. Valid Values: `true`: Created. `false`: not created.
        """
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[bool]]:
        """
        The status of the service Associated role. Valid Values: `true`: Created. `false`: not created.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "status", value)


class ServiceLinkedRole(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 __props__=None):
        """
        Using this resource can create SecurityCenter service-linked role : `AliyunServiceRolePolicyForSas`.  This Role is a Resource Access Management (RAM) role, which to obtain permissions to access another Alibaba Cloud service.

        For information about Security Center Service Role and how to use it, see [What is Security Center](https://www.alibabacloud.com/help/en/doc-detail/42302.htm).

        > **NOTE:** Available in v1.142.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        service_linked_role = alicloud.securitycenter.ServiceLinkedRole("serviceLinkedRole")
        ```

        ## Import

        SecurityCenter service-linked roles(SLR) can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:securitycenter/serviceLinkedRole:ServiceLinkedRole example <product_name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ServiceLinkedRoleArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Using this resource can create SecurityCenter service-linked role : `AliyunServiceRolePolicyForSas`.  This Role is a Resource Access Management (RAM) role, which to obtain permissions to access another Alibaba Cloud service.

        For information about Security Center Service Role and how to use it, see [What is Security Center](https://www.alibabacloud.com/help/en/doc-detail/42302.htm).

        > **NOTE:** Available in v1.142.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        service_linked_role = alicloud.securitycenter.ServiceLinkedRole("serviceLinkedRole")
        ```

        ## Import

        SecurityCenter service-linked roles(SLR) can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:securitycenter/serviceLinkedRole:ServiceLinkedRole example <product_name>
        ```

        :param str resource_name: The name of the resource.
        :param ServiceLinkedRoleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ServiceLinkedRoleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 __props__=None):
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ServiceLinkedRoleArgs.__new__(ServiceLinkedRoleArgs)

            __props__.__dict__["status"] = None
        super(ServiceLinkedRole, __self__).__init__(
            'alicloud:securitycenter/serviceLinkedRole:ServiceLinkedRole',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            status: Optional[pulumi.Input[bool]] = None) -> 'ServiceLinkedRole':
        """
        Get an existing ServiceLinkedRole resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] status: The status of the service Associated role. Valid Values: `true`: Created. `false`: not created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ServiceLinkedRoleState.__new__(_ServiceLinkedRoleState)

        __props__.__dict__["status"] = status
        return ServiceLinkedRole(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[bool]:
        """
        The status of the service Associated role. Valid Values: `true`: Created. `false`: not created.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetProductProductResult',
    'GetProductProductSkusResult',
    'GetProductProductSkusImageResult',
    'GetProductProductSkusPackageVersionResult',
    'GetProductsProductResult',
]

@pulumi.output_type
class GetProductProductResult(dict):
    def __init__(__self__, *,
                 code: str,
                 description: str,
                 name: str,
                 skuses: Sequence['outputs.GetProductProductSkusResult']):
        """
        :param str code: The code of the product.
        :param str description: The description of the product.
        :param str name: The name of the product.
        :param Sequence['GetProductProductSkusArgs'] skuses: A list of one element containing sku attributes of an object. Each element contains the following attributes:
        """
        pulumi.set(__self__, "code", code)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "skuses", skuses)

    @property
    @pulumi.getter
    def code(self) -> str:
        """
        The code of the product.
        """
        return pulumi.get(self, "code")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of the product.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the product.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def skuses(self) -> Sequence['outputs.GetProductProductSkusResult']:
        """
        A list of one element containing sku attributes of an object. Each element contains the following attributes:
        """
        return pulumi.get(self, "skuses")


@pulumi.output_type
class GetProductProductSkusResult(dict):
    def __init__(__self__, *,
                 images: Sequence['outputs.GetProductProductSkusImageResult'],
                 package_versions: Sequence['outputs.GetProductProductSkusPackageVersionResult'],
                 sku_code: str,
                 sku_name: str):
        """
        :param Sequence['GetProductProductSkusImageArgs'] images: The list of custom ECS images, Each element contains the following attributes:
        :param Sequence['GetProductProductSkusPackageVersionArgs'] package_versions: The list of package version details of this product sku, Each element contains the following attributes:
        :param str sku_code: The sku code of this product sku.
        :param str sku_name: The sku name of this product sku.
        """
        pulumi.set(__self__, "images", images)
        pulumi.set(__self__, "package_versions", package_versions)
        pulumi.set(__self__, "sku_code", sku_code)
        pulumi.set(__self__, "sku_name", sku_name)

    @property
    @pulumi.getter
    def images(self) -> Sequence['outputs.GetProductProductSkusImageResult']:
        """
        The list of custom ECS images, Each element contains the following attributes:
        """
        return pulumi.get(self, "images")

    @property
    @pulumi.getter(name="packageVersions")
    def package_versions(self) -> Sequence['outputs.GetProductProductSkusPackageVersionResult']:
        """
        The list of package version details of this product sku, Each element contains the following attributes:
        """
        return pulumi.get(self, "package_versions")

    @property
    @pulumi.getter(name="skuCode")
    def sku_code(self) -> str:
        """
        The sku code of this product sku.
        """
        return pulumi.get(self, "sku_code")

    @property
    @pulumi.getter(name="skuName")
    def sku_name(self) -> str:
        """
        The sku name of this product sku.
        """
        return pulumi.get(self, "sku_name")


@pulumi.output_type
class GetProductProductSkusImageResult(dict):
    def __init__(__self__, *,
                 image_id: str,
                 image_name: str,
                 region_id: str):
        """
        :param str image_id: The Ecs image id.
        :param str image_name: The Ecs image display name.
        :param str region_id: The Ecs image region.
        """
        pulumi.set(__self__, "image_id", image_id)
        pulumi.set(__self__, "image_name", image_name)
        pulumi.set(__self__, "region_id", region_id)

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> str:
        """
        The Ecs image id.
        """
        return pulumi.get(self, "image_id")

    @property
    @pulumi.getter(name="imageName")
    def image_name(self) -> str:
        """
        The Ecs image display name.
        """
        return pulumi.get(self, "image_name")

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> str:
        """
        The Ecs image region.
        """
        return pulumi.get(self, "region_id")


@pulumi.output_type
class GetProductProductSkusPackageVersionResult(dict):
    def __init__(__self__, *,
                 package_name: str,
                 package_version: str):
        """
        :param str package_name: The package name of this product sku package.
        :param str package_version: The package version of this product sku package. Currently, the API products can return package_version, but others can not for ensure.
        """
        pulumi.set(__self__, "package_name", package_name)
        pulumi.set(__self__, "package_version", package_version)

    @property
    @pulumi.getter(name="packageName")
    def package_name(self) -> str:
        """
        The package name of this product sku package.
        """
        return pulumi.get(self, "package_name")

    @property
    @pulumi.getter(name="packageVersion")
    def package_version(self) -> str:
        """
        The package version of this product sku package. Currently, the API products can return package_version, but others can not for ensure.
        """
        return pulumi.get(self, "package_version")


@pulumi.output_type
class GetProductsProductResult(dict):
    def __init__(__self__, *,
                 category_id: int,
                 code: str,
                 delivery_date: str,
                 delivery_way: str,
                 image_url: str,
                 name: str,
                 operation_system: str,
                 score: str,
                 short_description: str,
                 suggested_price: str,
                 supplier_id: int,
                 supplier_name: str,
                 tags: str,
                 target_url: str,
                 warranty_date: str):
        """
        :param int category_id: The Category ID of products. For more information, see [DescribeProducts](https://help.aliyun.com/document_detail/89834.htm).
        :param str code: The code of the product.
        :param str delivery_date: The delivery date of the product.
        :param str delivery_way: The delivery way of the product.
        :param str image_url: The image URL of the product.
        :param str name: The name of the product.
        :param str operation_system: The operation system of the product.
        :param str score: The rating information of the product.
        :param str short_description: The short description of the product.
        :param str suggested_price: The suggested price of the product.
        :param int supplier_id: The supplier id of the product.
        :param str supplier_name: The supplier name of the product.
        :param str tags: The tags of the product.
        :param str target_url: The detail page URL of the product.
        :param str warranty_date: The warranty date of the product.
        """
        pulumi.set(__self__, "category_id", category_id)
        pulumi.set(__self__, "code", code)
        pulumi.set(__self__, "delivery_date", delivery_date)
        pulumi.set(__self__, "delivery_way", delivery_way)
        pulumi.set(__self__, "image_url", image_url)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "operation_system", operation_system)
        pulumi.set(__self__, "score", score)
        pulumi.set(__self__, "short_description", short_description)
        pulumi.set(__self__, "suggested_price", suggested_price)
        pulumi.set(__self__, "supplier_id", supplier_id)
        pulumi.set(__self__, "supplier_name", supplier_name)
        pulumi.set(__self__, "tags", tags)
        pulumi.set(__self__, "target_url", target_url)
        pulumi.set(__self__, "warranty_date", warranty_date)

    @property
    @pulumi.getter(name="categoryId")
    def category_id(self) -> int:
        """
        The Category ID of products. For more information, see [DescribeProducts](https://help.aliyun.com/document_detail/89834.htm).
        """
        return pulumi.get(self, "category_id")

    @property
    @pulumi.getter
    def code(self) -> str:
        """
        The code of the product.
        """
        return pulumi.get(self, "code")

    @property
    @pulumi.getter(name="deliveryDate")
    def delivery_date(self) -> str:
        """
        The delivery date of the product.
        """
        return pulumi.get(self, "delivery_date")

    @property
    @pulumi.getter(name="deliveryWay")
    def delivery_way(self) -> str:
        """
        The delivery way of the product.
        """
        return pulumi.get(self, "delivery_way")

    @property
    @pulumi.getter(name="imageUrl")
    def image_url(self) -> str:
        """
        The image URL of the product.
        """
        return pulumi.get(self, "image_url")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the product.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="operationSystem")
    def operation_system(self) -> str:
        """
        The operation system of the product.
        """
        return pulumi.get(self, "operation_system")

    @property
    @pulumi.getter
    def score(self) -> str:
        """
        The rating information of the product.
        """
        return pulumi.get(self, "score")

    @property
    @pulumi.getter(name="shortDescription")
    def short_description(self) -> str:
        """
        The short description of the product.
        """
        return pulumi.get(self, "short_description")

    @property
    @pulumi.getter(name="suggestedPrice")
    def suggested_price(self) -> str:
        """
        The suggested price of the product.
        """
        return pulumi.get(self, "suggested_price")

    @property
    @pulumi.getter(name="supplierId")
    def supplier_id(self) -> int:
        """
        The supplier id of the product.
        """
        return pulumi.get(self, "supplier_id")

    @property
    @pulumi.getter(name="supplierName")
    def supplier_name(self) -> str:
        """
        The supplier name of the product.
        """
        return pulumi.get(self, "supplier_name")

    @property
    @pulumi.getter
    def tags(self) -> str:
        """
        The tags of the product.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="targetUrl")
    def target_url(self) -> str:
        """
        The detail page URL of the product.
        """
        return pulumi.get(self, "target_url")

    @property
    @pulumi.getter(name="warrantyDate")
    def warranty_date(self) -> str:
        """
        The warranty date of the product.
        """
        return pulumi.get(self, "warranty_date")


